package
Version:
v0.0.4
Opens a new window with list of versions in this module.
Published: Jul 22, 2025
License: MIT
Opens a new window with license information.
Imports: 1
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type ErrorResponse struct {
Error string `json:"error"`
Time time.Time `json:"timestamp"`
}
type HealthResponse struct {
Status string `json:"status"`
Time string `json:"timestamp"`
}
type QueryRequest struct {
SQL string `json:"sql" binding:"required"`
}
type QueryResponse struct {
Columns []string `json:"columns"`
Rows [][]interface{} `json:"rows"`
Count int `json:"count"`
Time string `json:"execution_time"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.